My personal code collection.

Link to [Github](https://github.com/thomascamminady/camminapy).

## Installation

Install via `pip`:

```bash
pip install camminapy
```


Install via `poetry`:

```bash
poetry add camminapy
```

## Development

To create the documentation, run:
```bash
make doc
```

To publish an updated version to PyPi:
```bash
make publish
```
